pub struct EmptyObject {}Trait Implementations
Sourceimpl Clone for EmptyObject
impl Clone for EmptyObject
Sourcefn clone(&self) -> EmptyObject
fn clone(&self) -> EmptyObject
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmptyObject
impl Debug for EmptyObject
Sourceimpl<'de> Deserialize<'de> for EmptyObject
impl<'de> Deserialize<'de> for EmptyObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<EmptyObject> for ()
impl From<EmptyObject> for ()
Sourcefn from(_value: EmptyResult)
fn from(_value: EmptyResult)
Converts to this type from the input type.
Sourceimpl JsonSchema for EmptyObject
impl JsonSchema for EmptyObject
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EmptyObject
impl PartialEq for EmptyObject
Sourcefn eq(&self, other: &EmptyObject) -> bool
fn eq(&self, other: &EmptyObject) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EmptyObject
impl Serialize for EmptyObject
impl Copy for EmptyObject
impl Eq for EmptyObject
impl StructuralPartialEq for EmptyObject