pub struct JsonRpcError {
pub jsonrpc: JsonRpcVersion2_0,
pub id: RequestId,
pub error: ErrorData,
}Fields
jsonrpc: JsonRpcVersion2_0id: RequestIderror: ErrorDataTrait Implementations
Sourceimpl Clone for JsonRpcError
impl Clone for JsonRpcError
Sourcefn clone(&self) -> JsonRpcError
fn clone(&self) -> JsonRpcError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonRpcError
impl Debug for JsonRpcError
Sourceimpl<'de> Deserialize<'de> for JsonRpcError
impl<'de> Deserialize<'de> for JsonRpcError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JsonRpcError
impl JsonSchema for JsonRpcError
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for JsonRpcError
impl PartialEq for JsonRpcError
Sourcefn eq(&self, other: &JsonRpcError) -> bool
fn eq(&self, other: &JsonRpcError) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for JsonRpcError
impl Serialize for JsonRpcError
impl StructuralPartialEq for JsonRpcError