pub struct Prompt {
pub name: String,
pub description: Option<String>,
pub arguments: Option<Vec<PromptArgument>>,
}Expand description
A prompt that can be used to generate text from a model
Fields
name: StringThe name of the prompt
description: Option<String>Optional description of what the prompt does
arguments: Option<Vec<PromptArgument>>Optional arguments that can be passed to customize the prompt
Implementations