pub struct PromptsCapability {
pub list_changed: Option<bool>,
}Fields
list_changed: Option<bool>Trait Implementations
Sourceimpl Clone for PromptsCapability
impl Clone for PromptsCapability
Sourcefn clone(&self) -> PromptsCapability
fn clone(&self) -> PromptsCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromptsCapability
impl Debug for PromptsCapability
Sourceimpl Default for PromptsCapability
impl Default for PromptsCapability
Sourcefn default() -> PromptsCapability
fn default() -> PromptsCapability
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PromptsCapability
impl<'de> Deserialize<'de> for PromptsCapability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PromptsCapability
impl JsonSchema for PromptsCapability
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PromptsCapability
impl PartialEq for PromptsCapability
Sourcefn eq(&self, other: &PromptsCapability) -> bool
fn eq(&self, other: &PromptsCapability) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PromptsCapability
impl Serialize for PromptsCapability
impl StructuralPartialEq for PromptsCapability