pub struct RawEmbeddedResource {
pub resource: ResourceContents,
}Fields
resource: ResourceContentsTrait Implementations
Sourceimpl AnnotateAble for RawEmbeddedResource
impl AnnotateAble for RawEmbeddedResource
fn optional_annotate(self, annotations: Option<Annotations>) -> Annotated<Self>where
Self: Sized,
fn annotate(self, annotations: Annotations) -> Annotated<Self>where
Self: Sized,
fn no_annotation(self) -> Annotated<Self>where
Self: Sized,
fn with_audience(self, audience: Vec<Role>) -> Annotated<Self>where
Self: Sized,
fn with_priority(self, priority: f32) -> Annotated<Self>where
Self: Sized,
fn with_timestamp(self, timestamp: DateTime<Utc>) -> Annotated<Self>where
Self: Sized,
fn with_timestamp_now(self) -> Annotated<Self>where
Self: Sized,
Sourceimpl Clone for RawEmbeddedResource
impl Clone for RawEmbeddedResource
Sourcefn clone(&self) -> RawEmbeddedResource
fn clone(&self) -> RawEmbeddedResource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RawEmbeddedResource
impl Debug for RawEmbeddedResource
Sourceimpl<'de> Deserialize<'de> for RawEmbeddedResource
impl<'de> Deserialize<'de> for RawEmbeddedResource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RawEmbeddedResource
impl JsonSchema for RawEmbeddedResource
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RawEmbeddedResource
impl PartialEq for RawEmbeddedResource
Sourcefn eq(&self, other: &RawEmbeddedResource) -> bool
fn eq(&self, other: &RawEmbeddedResource) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RawEmbeddedResource
impl Serialize for RawEmbeddedResource
impl StructuralPartialEq for RawEmbeddedResource