pub struct ToolsCapability {
pub list_changed: Option<bool>,
}Fields
list_changed: Option<bool>Trait Implementations
Sourceimpl Clone for ToolsCapability
impl Clone for ToolsCapability
Sourcefn clone(&self) -> ToolsCapability
fn clone(&self) -> ToolsCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolsCapability
impl Debug for ToolsCapability
Sourceimpl Default for ToolsCapability
impl Default for ToolsCapability
Sourcefn default() -> ToolsCapability
fn default() -> ToolsCapability
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ToolsCapability
impl<'de> Deserialize<'de> for ToolsCapability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolsCapability
impl JsonSchema for ToolsCapability
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ToolsCapability
impl PartialEq for ToolsCapability
Sourcefn eq(&self, other: &ToolsCapability) -> bool
fn eq(&self, other: &ToolsCapability) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ToolsCapability
impl Serialize for ToolsCapability
impl StructuralPartialEq for ToolsCapability