pub type SetLevelRequest = Request<SetLevelRequestMethod, SetLevelRequestParam>;Aliased Type
pub struct SetLevelRequest {
pub method: SetLevelRequestMethod,
pub params: SetLevelRequestParam,
pub extensions: Extensions,
}Fields
method: SetLevelRequestMethodparams: SetLevelRequestParamextensions: Extensionsextensions will carry anything possible in the context, including Meta
this is similar with the Extensions in http crate